@@ -2,7 +2,7 @@
 #
 # (c) 2005 - 2015, Arthur Corliss <corliss@digitalmages.com>
 #
-# $Id: lib/Paranoid/BerkeleyDB.pm, 2.01 2016/06/17 11:24:54 acorliss Exp $
+# $Id: lib/Paranoid/BerkeleyDB.pm, 2.02 2016/06/21 19:51:06 acorliss Exp $
 #
 #    This software is licensed under the same terms as Perl, itself.
 #    Please see http://dev.perl.org/licenses/ for more information.
@@ -31,7 +31,7 @@ use Paranoid::BerkeleyDB::Env;
 use Paranoid::BerkeleyDB::Db;
 use Carp;
 
-($VERSION) = ( q$Revision: 2.01 $ =~ /(\d+(?:\.\d+)+)/sm );
+($VERSION) = ( q$Revision: 2.02 $ =~ /(\d+(?:\.\d+)+)/sm );
 
 use vars qw(@ISA @_properties @_methods);
 
@@ -45,6 +45,8 @@ use vars qw(@ISA @_properties @_methods);
     );
 @_methods = ( [ CEH_PUB, 'dbh' ], );
 
+our $db46 = 0;
+
 #####################################################################
 #
 # module code follows
@@ -66,6 +68,11 @@ sub _initialize {
     pdebug( 'entering w/%s', PDLEVEL1, %params );
     pIn();
 
+    # Set db46 flag
+    $db46 = 1
+        if DB_VERSION_MAJOR > 4
+            or ( DB_VERSION_MAJOR == 4 and DB_VERSION_MINOR >= 6 );
+
     # Set up the environment
     if ( exists $params{Home} ) {
         $env = new Paranoid::BerkeleyDB::Env '-Home' => $params{Home};
@@ -244,12 +251,15 @@ sub EXISTS {
     my $obj = shift;
     my $key = shift;
     my $dbh = $obj->dbh;
-    my $rv;
+    my ( $val, $rv );
 
     pdebug( 'entering w/(%s)', PDLEVEL3, $key );
     pIn();
 
-    $rv = !$dbh->db_exists($key);
+    $rv =
+          $db46
+        ? $dbh->db_exists($key) != DB_NOTFOUND
+        : $dbh->db_get( $key, $val ) == 0;
 
     pOut();
     pdebug( 'leaving w/rv: %s', PDLEVEL3, $rv );
@@ -384,7 +394,7 @@ Paranoid::BerkeleyDB -- BerkeleyDB Wrapper
 
 =head1 VERSION
 
-$Id: lib/Paranoid/BerkeleyDB.pm, 2.01 2016/06/17 11:24:54 acorliss Exp $
+$Id: lib/Paranoid/BerkeleyDB.pm, 2.02 2016/06/21 19:51:06 acorliss Exp $
 
 =head1 SYNOPSIS
 
